@@ -315,7 +315,7 @@ SEXP tmb_invQ_tril_halfdiag(SEXP Lfac){
   CHM_SP iQ = tmb_inv_super(L, &c);
   half_diag(iQ);
   iQ->stype=0; /* Change to non-sym */
-  return M_chm_sparse_to_SEXP(iQ, 1 /* Free */ , -1 /* uplo="L" */ , 0, "", R_NilValue);
+  return M_chm_sparse_to_SEXP(iQ, 1 /* Free */ , -1 /* uplo="L" */ , 0, "N" /* Not unit */, R_NilValue);
 }
 
 /* Given sparse matrices A and B (sorted columns).
